-- ----------------------------
-- 园区基本信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_park`;
CREATE TABLE `mortals_agent_park`
(
    `id`             int(20) NOT NULL AUTO_INCREMENT COMMENT '园区id',
    `name`           varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '园区名称',
    `code`           varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '园区编码',
    `introduction`   text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '园区介绍',
    `phone`          varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci  DEFAULT NULL COMMENT '电话号码',
    `address`        varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '园区地址',
    `icon`           varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '园区图标',
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime                                                DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime                                                DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8
  COLLATE = utf8_general_ci
  ROW_FORMAT = DYNAMIC COMMENT ='园区基本信息';

-- ----------------------------
-- 企业公司基本信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_company`;
CREATE TABLE `mortals_agent_company`
(
    `id`                          int(20) NOT NULL AUTO_INCREMENT COMMENT '公司id',
    `park_id`                     bigint(20) DEFAULT NULL COMMENT '所属园区id',
    `park_name`                   varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '园区名称',
    `name`                        varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '公司名称',
    `apply_name`                  varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '申请人姓名',
    `social_credit_code`          varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '统一社会信用代码',
    `introduction`                text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '公司介绍',
    `phone`                       varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci  DEFAULT NULL COMMENT '电话号码',
    `address`                     varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '企业公司地址',
    `qr_code`                     varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '二维码',
    `applicant_idcard_number`     varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '申请人身份证code',
    `applicant_idcard_front_path` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '申请人身份证正面照片',
    `applicant_idcard_back_path`  varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '申请人身份证反面照片',
    `business_license_path`       varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '申请人营业执照照片',
    `application_status`          tinyint(1) DEFAULT '0' COMMENT '认证状态(1.待审核,2.已认证,3.审核拒绝)',
    `declaration_count`           int(9) DEFAULT '0' COMMENT '申报次数',
    `remark`                      varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id`              bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time`                 datetime                                                DEFAULT NULL COMMENT '创建时间',
    `update_time`                 datetime                                                DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8
  COLLATE = utf8_general_ci
  ROW_FORMAT = DYNAMIC COMMENT ='企业基本信息';



-- ----------------------------
-- 事项分类表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_category`;
CREATE TABLE `mortals_agent_category`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `category_code`  varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类编码',
    `category_name`  varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类名称',
    `sort`           int(4) NULL DEFAULT 0 COMMENT '排序字段',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX            `idx_category_code`(`category_code`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '事项分类';


-- ----------------------------
-- 分类事项子表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_matter_sub`;
CREATE TABLE `mortals_agent_matter_sub`
(
    `id`               bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `category_id`      bigint(20) DEFAULT NULL COMMENT '分类ID',
    `category_code`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类编码',
    `category_name`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类名称',
    `matter_id`        bigint(20) DEFAULT NULL COMMENT '事项id',
    `matter_name`      varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '事项名称',
    `matter_code`      varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '事项编码',
    `area_code`        varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '区域编码',
    `area_name`        varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '区域名称',
    `area_level`       tinyint(2) NULL DEFAULT 1 COMMENT '区域等级(1.省，2.地市州，3.区县，4.街道，5.社区)',
    `dept_id`          bigint(20) NULL DEFAULT NULL COMMENT '办理单位ID',
    `dept_name`        varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '办理单位名称',
    `sort`             int(4) NULL DEFAULT 0 COMMENT '排序字段',
    `remark`           varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id`   bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_user_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
    `create_time`      datetime DEFAULT NULL COMMENT '创建时间',
    `update_time`      datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX              `idx_category_id`(`category_id`) USING BTREE,
    INDEX              `idx_dept_id`(`dept_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '分类事项';



-- ----------------------------
-- 企业代办申报
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_declare`;
CREATE TABLE `mortals_agent_declare`
(
    `id`               bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `matter_id`        bigint(20) DEFAULT NULL COMMENT '事项id',
    `matter_name`      varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '事项名称',
    `matter_code`      varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '事项编码',
    `area_name`        varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '区域名称',
    `dept_id`          bigint(20) NULL DEFAULT NULL COMMENT '办理单位ID',
    `dept_name`        varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '办理单位名称',
    `park_id`          bigint(20) DEFAULT NULL COMMENT '所属园区id',
    `park_name`        varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '园区名称',
    `company_id`       bigint(20) DEFAULT NULL COMMENT '所属公司id',
    `company_name`     varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '公司名称',
    `category_id`      bigint(20) DEFAULT NULL COMMENT '分类ID',
    `category_code`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类编码',
    `category_name`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '分类名称',
    `apply_id`         bigint(20) DEFAULT NULL COMMENT '申请人id',
    `apply_open_id`    varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '申请人openId',
    `apply_name`       varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '申请人名称',
    `content`          varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '提交诉求内容',
    `submit_time`      datetime                                                DEFAULT NULL COMMENT '提交申报时间',
    `agent_user_id`     bigint(20)  DEFAULT NULL COMMENT '代办人id',
    `agent_user_name`       varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '代办人名称',
    `assign_time`      datetime                                                DEFAULT NULL COMMENT '分派时间',
    `result`           varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '办理结果',
    `fin_time`         datetime                                                DEFAULT NULL COMMENT '办理完结时间',
    `declare_status`   tinyint(2) DEFAULT '0' COMMENT '申报状态(0.草稿,1.办理中,2.完结,99.已撤回)',
    `sort`             int(4) NULL DEFAULT 0 COMMENT '排序字段',
    `remark`           varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id`   bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_user_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '创建用户名称',
    `create_time`      datetime                                                DEFAULT NULL COMMENT '创建时间',
    `update_time`      datetime                                                DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX              `idx_category_id`(`category_id`) USING BTREE,
    INDEX              `idx_dept_id`(`dept_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '企业代办申报';



-- ----------------------------
-- 企业代办申报图片
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_declare_images`;
CREATE TABLE `mortals_agent_declare_images`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `declare_id`     bigint(20) DEFAULT NULL COMMENT '申报id,对应所属 declare.id',
    `image_path`     VARCHAR(500) NOT NULL COMMENT '图片U',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX            `idx_declare_id`(`declare_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '企业代办申报图片';



-- ----------------------------
-- 企业代办申报办结图片
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_declare_fin_images`;
CREATE TABLE `mortals_agent_declare_fin_images`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `declare_id`     bigint(20) DEFAULT NULL COMMENT '申报id,对应所属 declare.id',
    `image_path`     VARCHAR(500) NOT NULL COMMENT '图片U',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX            `idx_declare_id`(`declare_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '企业代办申报办结图片';



-- ----------------------------
-- 用户代办帮办评价
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_evaluation_info`;
CREATE TABLE `mortals_agent_evaluation_info`
(
    `id`             bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
    `declare_id`     bigint(20) DEFAULT NULL COMMENT '申报id,对应所属 declare.id',
    `evaluator_id`   bigint(20) DEFAULT NULL COMMENT '评价人 ID，关联用户表',
    `evaluator_name` VARCHAR(500) NOT NULL COMMENT '评价人姓名或昵称',
    `score`          tinyint(2) DEFAULT '5' COMMENT '评分，一般 1~5 星',
    `comment`        VARCHAR(512) NOT NULL COMMENT '评价内容',
    `suggestion`     VARCHAR(512) NOT NULL COMMENT '意见建议',
    `eval_status`    tinyint(2) NULL DEFAULT 1 COMMENT '评价状态(1.正常，2.删除，3.隐藏)',
    `remark`         varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT '' COMMENT '备注',
    `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
    `create_time`    datetime DEFAULT NULL COMMENT '创建时间',
    `update_time`    datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX            `idx_declare_id`(`declare_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci COMMENT = '用户代办帮办评价';



DROP TABLE IF EXISTS `mortals_agent_user`;
CREATE TABLE `mortals_agent_user` (
        `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '用户ID，主键，自增长',
        `loginName` varchar(50) DEFAULT NULL COMMENT '登录名',
        `loginPwd` varchar(128) DEFAULT NULL COMMENT '登录密码，使用md5双次加密',
        `loginLimitAddress` varchar(200) DEFAULT NULL COMMENT '登录限制地址，多个IP地址用逗号分隔，可以使用IP段匹配，如：172.17.*非空：则只能该值内的IP可以登录',
        `realName` varchar(64) DEFAULT NULL COMMENT '用户名',
        `mobile` varchar(21) DEFAULT NULL COMMENT '用户手机号',
        `phone` varchar(21) DEFAULT NULL COMMENT '用户联系电话',
        `email` varchar(50) DEFAULT NULL COMMENT '用户邮箱',
        `qq` varchar(20) DEFAULT NULL COMMENT 'QQ号码',
        `open_id`           varchar(128) CHARACTER SET utf8 DEFAULT NULL COMMENT 'openId,绑定企业',
        `company_id`        bigint(20) DEFAULT NULL COMMENT '绑定公司企业id',
        `customerId` bigint(20) DEFAULT null COMMENT '代办员工id',
        `userType` tinyint(2) DEFAULT NULL COMMENT '用户类型(0.系统用户,1.普通用户,2.公司企业用户,3.代办帮办员工)',
        `siteIds` varchar(512) DEFAULT NULL COMMENT '所属站点id,多个逗号分隔',
        `areaCodes` varchar(512) DEFAULT NULL COMMENT '所属区域code,多个逗号分隔',
        `status` tinyint(2) DEFAULT NULL COMMENT '用户状态(0.停用，1.正常，2.冻结，3.销户，4.离职)',
        `createTime` datetime DEFAULT NULL COMMENT '创建时间',
        `createUserId` bigint(20) DEFAULT NULL COMMENT '创建用户',
        `createUserName` varchar(50) DEFAULT NULL COMMENT '创建用户名称',
        `lastLoginTime` datetime DEFAULT NULL COMMENT '最后一次登录时间',
        `lastLoginAddress` varchar(21) DEFAULT NULL COMMENT '最后一次登录地址',
        PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='用户信息业务';




-- ----------------------------
-- 代办帮办人员
-- ----------------------------
DROP TABLE IF EXISTS `mortals_agent_staff`;
CREATE TABLE `mortals_agent_staff`  (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `user_id` bigint(20) NOT NULL COMMENT 'user表外键，user.id',
  `login_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '登录名',
  `login_pwd` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '登录密码',
  `real_name` varchar(64) DEFAULT NULL COMMENT '真实姓名',
  `photo_path` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '照片',
  `phone_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '联系方式',
  `dept_name` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '所属部门',
  `total_num`          int(4) DEFAULT '0' COMMENT '累计代办次数',
  `total_score`          int(4) DEFAULT '0' COMMENT '累计评分',
  `remark` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '备注',
  `create_user_id` bigint(20) DEFAULT NULL COMMENT '创建用户',
  `create_time`    datetime DEFAULT NULL COMMENT '创建时间',
  `update_time`    datetime DEFAULT NULL COMMENT '更新时间',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE KEY `idx_loginName` (`login_Name`) USING BTREE
) CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '代办帮办人员';



ALTER TABLE mortals_agent_declare ADD COLUMN `agent_user_id`     bigint(20)  DEFAULT NULL COMMENT '代办人id' AFTER submit_time;
ALTER TABLE mortals_agent_declare ADD COLUMN `agent_user_name`       varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '代办人名称' AFTER agent_user_id;
ALTER TABLE mortals_agent_declare ADD COLUMN `assign_time`      datetime                                                DEFAULT NULL COMMENT '分派时间' AFTER agent_user_name;
ALTER TABLE mortals_agent_declare ADD COLUMN `assign_user_id`       bigint(20)  DEFAULT NULL COMMENT '分配人id' AFTER AFTER assign_time;
ALTER TABLE mortals_agent_declare ADD COLUMN `assign_user_name`       varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '分配人名称' AFTER assign_user_id;

ALTER TABLE mortals_agent_user ADD COLUMN `customerId` bigint(20) DEFAULT null COMMENT '代办员工id' AFTER company_id;