package com.mortals.xhx.module.category.service.impl;
import com.mortals.framework.model.PageInfo;
import org.springframework.beans.BeanUtils;

import java.util.Map;
import java.util.function.Function;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.category.dao.CategoryDao;
import com.mortals.xhx.module.category.model.CategoryEntity;
import com.mortals.xhx.module.category.service.CategoryService;
import org.springframework.beans.factory.annotation.Autowired;
import com.mortals.xhx.module.matter.model.MatterSubEntity;
import com.mortals.xhx.module.matter.model.MatterSubQuery;
import com.mortals.xhx.module.matter.service.MatterSubService;
import org.springframework.util.ObjectUtils;
import java.util.Date;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import lombok.extern.slf4j.Slf4j;
/**
* CategoryService
* 事项分类 service实现
*
* @author zxfei
* @date 2025-04-27
*/
@Service("categoryService")
@Slf4j
public class CategoryServiceImpl extends AbstractCRUDServiceImpl<CategoryDao, CategoryEntity, Long> implements CategoryService {
    @Autowired
    private MatterSubService matterSubService;

    @Override
    protected void findAfter(CategoryEntity params,PageInfo pageInfo, Context context, List<CategoryEntity> list) throws AppException {
        fillSubData(list);
        super.findAfter(params,pageInfo, context, list);
    }
    @Override
    protected void findAfter(CategoryEntity params, Context context, List<CategoryEntity> list) throws AppException {
        fillSubData(list);
        super.findAfter(params, context, list);
    }

    private void fillSubData(List<CategoryEntity> list) {
        List<Long> idList = list.stream().map(i -> i.getId()).collect(Collectors.toList());
        if(ObjectUtils.isEmpty(idList))return;
        Map<Long, List<MatterSubEntity>> matterSubListMap = matterSubService
                .find(new MatterSubQuery().categoryIdList(idList)).parallelStream()
                .collect(Collectors.groupingBy(MatterSubEntity::getCategoryId));
        list.forEach(item -> item.setMatterSubList(matterSubListMap.get(item.getId())));
    }

    
    @Override
    protected void saveAfter(CategoryEntity entity, Context context) throws AppException {
        if(!ObjectUtils.isEmpty(entity.getMatterSubList())){
            entity.getMatterSubList().stream().peek(item->{
                item.setCategoryId(entity.getId());
                item.setCreateUserId(this.getContextUserId(context));
                item.setCreateTime(new Date());
            }).count();
            matterSubService.save(entity.getMatterSubList());
        }
        super.saveAfter(entity, context);
    }

    @Override
    protected void updateAfter(CategoryEntity entity, Context context) throws AppException {
        if(!ObjectUtils.isEmpty(entity.getMatterSubList())){
            Long[] matterSubIds = matterSubService.find(new MatterSubQuery().categoryId(entity.getId())).stream().map(MatterSubEntity::getId).toArray(Long[]::new);
            matterSubService.remove(matterSubIds,context);
            entity.getMatterSubList().stream().peek(item ->{
                item.setCategoryId(entity.getId());
                item.setCreateUserId(this.getContextUserId(context));
                item.setCreateTime(new Date());
                item.setUpdateUserId(this.getContextUserId(context));
                item.setUpdateTime(new Date());
            }).count();
            matterSubService.save(entity.getMatterSubList());
        }
        super.updateAfter(entity, context);
    }

    @Override
    protected void removeAfter(Long[] ids, Context context, int result) throws AppException {
        List<MatterSubEntity> matterSublist = matterSubService.find(new MatterSubQuery().categoryIdList(Arrays.asList(ids)));
        matterSubService.removeList(matterSublist,context);
        super.removeAfter(ids, context, result);
    }
}