package com.mortals.xhx.module.evaluation.service.impl;

import com.mortals.framework.common.Rest;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.module.declare.model.DeclareEntity;
import com.mortals.xhx.module.declare.service.DeclareService;
import com.mortals.xhx.module.staff.service.StaffService;
import org.springframework.beans.BeanUtils;

import java.util.function.Function;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.evaluation.dao.EvaluationInfoDao;
import com.mortals.xhx.module.evaluation.model.EvaluationInfoEntity;
import com.mortals.xhx.module.evaluation.service.EvaluationInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.ObjectUtils;

/**
 * EvaluationInfoService
 * 用户代办帮办评价 service实现
 *
 * @author zxfei
 * @date 2025-04-27
 */
@Service("evaluationInfoService")
@Slf4j
public class EvaluationInfoServiceImpl extends AbstractCRUDServiceImpl<EvaluationInfoDao, EvaluationInfoEntity, Long> implements EvaluationInfoService {

    @Autowired
    private DeclareService declareService;
    @Autowired
    private StaffService staffService;

    @Override
    protected void saveAfter(EvaluationInfoEntity entity, Context context) throws AppException {
        if (updateStaffScore(entity, context)) return;
        super.saveAfter(entity, context);
    }

    private boolean updateStaffScore(EvaluationInfoEntity entity, Context context) {
        //更新代办人累计评分
        if(ObjectUtils.isEmpty(entity.getDeclareId())) return true;
        DeclareEntity declareEntity = declareService.get(entity.getDeclareId(), context);
        if (ObjectUtils.isEmpty(declareEntity)) return true;
        staffService.updateAgentUserTotalScore(declareEntity.getAgentUserId(), context);
        return false;
    }

    @Override
    protected void updateAfter(EvaluationInfoEntity entity, Context context) throws AppException {
        if (updateStaffScore(entity, context)) return;
        super.updateAfter(entity, context);
    }
}