package com.mortals.xhx.module.staff.service.impl;

import com.mortals.framework.common.Rest;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.util.SecurityUtil;
import com.mortals.xhx.base.system.role.model.RoleUserQuery;
import com.mortals.xhx.base.system.role.service.RoleUserService;
import com.mortals.xhx.base.system.user.model.UserEntity;
import com.mortals.xhx.base.system.user.service.UserService;
import com.mortals.xhx.common.code.DeclareStatusEnum;
import com.mortals.xhx.module.declare.model.DeclareQuery;
import com.mortals.xhx.module.declare.service.DeclareService;
import com.mortals.xhx.module.evaluation.model.EvaluationInfoEntity;
import com.mortals.xhx.module.evaluation.model.EvaluationInfoQuery;
import com.mortals.xhx.module.evaluation.service.EvaluationInfoService;
import com.mortals.xhx.module.staff.model.StaffQuery;
import org.springframework.beans.BeanUtils;

import java.util.Arrays;
import java.util.List;
import java.util.function.Function;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.staff.dao.StaffDao;
import com.mortals.xhx.module.staff.model.StaffEntity;
import com.mortals.xhx.module.staff.service.StaffService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.ObjectUtils;

/**
 * StaffService
 * 代办帮办人员 service实现
 *
 * @author zxfei
 * @date 2025-05-08
 */
@Service("staffService")
@Slf4j
public class StaffServiceImpl extends AbstractCRUDServiceImpl<StaffDao, StaffEntity, Long> implements StaffService {
    @Autowired
    private UserService userService;
    @Autowired
    private DeclareService declareService;
    @Autowired
    private EvaluationInfoService evaluationInfoService;
    @Autowired
    private RoleUserService roleUserService;



    @Override
    protected void saveBefore(StaffEntity entity, Context context) throws AppException {
        //查询登录名是否存在
        boolean bool = userService.existUser(entity.getLoginName(), this.getContextUserId(context));
        if (bool) throw new AppException("登录名已存在！");

        // userService.doCheckUser(entity.getLoginName(), entity.getLoginPwd());
        super.saveBefore(entity, context);
    }

    @Override
    protected void saveAfter(StaffEntity entity, Context context) throws AppException {
        //创建用户
        UserEntity userEntity = new UserEntity();
        userEntity.initAttrValue();
        userEntity.setLoginName(entity.getLoginName());
        String password = null;
        try {
            password = SecurityUtil.md5DoubleEncoding(entity.getLoginPwd());
        } catch (Exception e) {
            throw new RuntimeException(e);
        }

        userEntity.setLoginPwd(password);
        userEntity.setRealName(entity.getRealName());
        userEntity.setMobile(entity.getPhoneNumber());
        userEntity.setPhone(entity.getPhoneNumber());
        userEntity.setCustomerId(entity.getId());

        userService.getUserDao().insert(userEntity);

        //更新默认用户角色
        RoleUserQuery roleUserQuery = new RoleUserQuery();
        roleUserQuery.setUserId(userEntity.getId());
        roleUserQuery.setRoleIdList(Arrays.asList(3L));
        roleUserService.doDistributionRole(roleUserQuery);


        entity.setUserId(userEntity.getId());
        this.dao.update(entity);
        super.saveAfter(entity, context);
    }


    @Override
    protected void updateBefore(StaffEntity entity, Context context) throws AppException {
        //查询登录名是否存在
        boolean bool = userService.existUser(entity.getLoginName(), entity.getUserId());
        if (bool) throw new AppException("登录名已存在！");

        super.updateBefore(entity, context);
    }

    @Override
    protected void updateAfter(StaffEntity entity, Context context) throws AppException {
        //更新用户
        UserEntity userEntity = userService.get(entity.getUserId(), context);
        if (!ObjectUtils.isEmpty(userEntity)) {
            userEntity.setLoginName(entity.getLoginName());
            String password = null;
            try {
                password = SecurityUtil.md5DoubleEncoding(entity.getLoginPwd());
            } catch (Exception e) {
                throw new RuntimeException(e);
            }

            userEntity.setLoginPwd(password);
            userEntity.setRealName(entity.getRealName());
            userEntity.setMobile(entity.getPhoneNumber());
            userEntity.setPhone(entity.getPhoneNumber());
            userService.getUserDao().update(userEntity);

            //更新默认用户角色
            RoleUserQuery roleUserQuery = new RoleUserQuery();
            roleUserQuery.setUserId(userEntity.getId());
            roleUserQuery.setRoleIdList(Arrays.asList(3L));
            roleUserService.doDistributionRole(roleUserQuery);

        }

        super.updateAfter(entity, context);
    }


    @Override
    public Rest<Void> updateAgentUserRecordNum(Long agentUserId, Context context) {

        StaffEntity staffEntity = this.selectOne(new StaffQuery().userId(agentUserId), context);
      //  StaffEntity staffEntity = this.get(agentUserId, context);
        if (ObjectUtils.isEmpty(staffEntity)) throw new AppException("用户不存在");
        DeclareQuery declareQuery = new DeclareQuery();
        declareQuery.setAgentUserId(staffEntity.getUserId());
        declareQuery.setDeclareStatus(DeclareStatusEnum.完结.getValue());
        int count = declareService.count(declareQuery, context);
        staffEntity.setTotalNum(count);
        dao.update(staffEntity);

        return Rest.ok();
    }

    @Override
    public Rest<Void> updateAgentUserTotalScore(Long agentUserId, Context context) {

        StaffEntity staffEntity = this.selectOne(new StaffQuery().userId(agentUserId), context);
        if (ObjectUtils.isEmpty(staffEntity)) throw new AppException("用户不存在");

        DeclareQuery declareQuery = new DeclareQuery();
        declareQuery.setAgentUserId(agentUserId);
        declareQuery.setDeclareStatus(DeclareStatusEnum.完结.getValue());
        List<Long> declareIdList = declareService.find(declareQuery).stream().map(i -> i.getId()).collect(Collectors.toList());

        if(!ObjectUtils.isEmpty(declareIdList)){
            EvaluationInfoQuery evaluationInfoQuery = new EvaluationInfoQuery();
            evaluationInfoQuery.setDeclareIdList(declareIdList);
            int sum = (int)evaluationInfoService.find(evaluationInfoQuery, context)
                    .stream().collect(Collectors.summarizingInt(EvaluationInfoEntity::getScore)).getSum();

            staffEntity.setTotalScore(sum);
            dao.update(staffEntity);
        }
        return Rest.ok();
    }
}